<a name="v3.3.0"></a>
## [v3.3.0](https://github.com/alexseitsinger/birdhouse-toolbox/compare/v3.2.0...v3.3.0) (2019-06-28)

### Features
- Adds create command to reports group. ([ab9b81d](https://github.com/alexseitsinger/birdhouse-toolbox/commit/ab9b81d40aae4f0b0ddb48352bebe99a7c60e6e9))
- Adds get_posts library modules. ([6e4e249](https://github.com/alexseitsinger/birdhouse-toolbox/commit/6e4e24939877a8605269cda8f18aa7267fb6e23c))
- Adds reports group to cli. ([7c8d926](https://github.com/alexseitsinger/birdhouse-toolbox/commit/7c8d92685313c32b8d1523e954b5c85328c08a25))
- Adds reports to cli and library. ([255dd59](https://github.com/alexseitsinger/birdhouse-toolbox/commit/255dd594de810727e15e0ea43ed6825430471928))


<a name="v3.2.0"></a>
## [v3.2.0](https://github.com/alexseitsinger/birdhouse-toolbox/compare/v3.1.0...v3.2.0) (2019-06-27)

### Bug Fixes
- Accepts an HTML string or path as content. ([78d902a](https://github.com/alexseitsinger/birdhouse-toolbox/commit/78d902a9711d6c0df1ff65a9966bdca6d88c1335))


<a name="v3.1.0"></a>
## [v3.1.0](https://github.com/alexseitsinger/birdhouse-toolbox/compare/v3.0.0...v3.1.0) (2019-06-27)

### Bug Fixes
- Adds authentication header to request. ([f681250](https://github.com/alexseitsinger/birdhouse-toolbox/commit/f6812507057b6532aa29a01a0915ab96b1c297d7))
- Adds MEDIA_URI to settings. ([b478de1](https://github.com/alexseitsinger/birdhouse-toolbox/commit/b478de182a795cc7cb3ffadb592bce7787d21283))

### Code Refactoring
- Adds featured_media to create_post. ([517363b](https://github.com/alexseitsinger/birdhouse-toolbox/commit/517363bfb5f5985cc81b4955435e7d72f2c0565d))
- Refines exception messages. ([070f450](https://github.com/alexseitsinger/birdhouse-toolbox/commit/070f450702dc122e9fcf8fa7542473b714efa372))

### Features
- Adds settings. ([f3a1d0a](https://github.com/alexseitsinger/birdhouse-toolbox/commit/f3a1d0a8b0485312ca7d29309fcb9527cc45699b))


<a name="v3.0.0"></a>
## [v3.0.0](https://github.com/alexseitsinger/birdhouse-toolbox/compare/v2.0.0...v3.0.0) (2019-06-27)

### Bug Fixes
- Adds default value for arg. ([492b3e3](https://github.com/alexseitsinger/birdhouse-toolbox/commit/492b3e38032f369059a5bd112ac9248b762e58f7))
- Creates config file if none exists. ([1697266](https://github.com/alexseitsinger/birdhouse-toolbox/commit/1697266d2ef6b17c19b55a91a6f0a7f22d821bd4))
- Fixes import. ([7532a58](https://github.com/alexseitsinger/birdhouse-toolbox/commit/7532a587473908ce68e1c739a2c5fc1f784610f7))
- Renames settings variable. ([04b0f39](https://github.com/alexseitsinger/birdhouse-toolbox/commit/04b0f39f985784884b8adff72019c61604dbb392))
- Renames settings variable. ([3f17c24](https://github.com/alexseitsinger/birdhouse-toolbox/commit/3f17c24a7e2eb05173b2ae32c310c1ba2ca2c1c2))
- Updates module to use auth headers, and more. ([c77b4c8](https://github.com/alexseitsinger/birdhouse-toolbox/commit/c77b4c8c65978bf14f8270e070080ffa87d59fba))

### Code Refactoring
- Adds exception instead of return dict. ([6f0222a](https://github.com/alexseitsinger/birdhouse-toolbox/commit/6f0222a4b6d2375d864427921bf4cdccf559f0af))
- Renames analytics to ga. ([55f45f3](https://github.com/alexseitsinger/birdhouse-toolbox/commit/55f45f3ea078abd5bd635579f06459eba263a9f4))
- Renames url arg to site_url. ([7bbc6bf](https://github.com/alexseitsinger/birdhouse-toolbox/commit/7bbc6bfb7a45eba1f24084bf97800e1de8e6baf2))

### Features
- Adds categories to post data. ([3a196c0](https://github.com/alexseitsinger/birdhouse-toolbox/commit/3a196c0d5269651a9df252a0fe10975937c2010b))
- Adds media option. ([fa95ab3](https://github.com/alexseitsinger/birdhouse-toolbox/commit/fa95ab31788a79e26a480027f5d001d74ebf639a))
- Adds module for get/set categories on posts. ([915e816](https://github.com/alexseitsinger/birdhouse-toolbox/commit/915e81643525ba174a442934d02a318214e45358))
- Adds module for uploading media. ([592cca6](https://github.com/alexseitsinger/birdhouse-toolbox/commit/592cca63b032850e9ae21a84806cc40001e15cd7))


<a name="v2.0.0"></a>
## [v2.0.0](https://github.com/alexseitsinger/birdhouse-toolbox/compare/v1.0.0...v2.0.0) (2019-06-27)

### Code Refactoring
- Adds shorter names. ([64dfcb9](https://github.com/alexseitsinger/birdhouse-toolbox/commit/64dfcb96433dcb588eaae2ca9f42b6f8e5ccaa4e))


<a name="v1.0.0"></a>
## [v1.0.0](https://github.com/alexseitsinger/birdhouse-toolbox/compare/v0.2.0...v1.0.0) (2019-06-27)

### Code Refactoring
- Changes to use library methods. ([2e116ff](https://github.com/alexseitsinger/birdhouse-toolbox/commit/2e116ffc9c8658fe963a2864357c4b576b950673))
- Removes unnecessary module. ([8306554](https://github.com/alexseitsinger/birdhouse-toolbox/commit/83065542f6ae2bbf80e32d1b68ac4a690f8e8329))
- Updates settings. ([26c6152](https://github.com/alexseitsinger/birdhouse-toolbox/commit/26c615224412a8befad8237f201e117689db58c0))
- Utils renamed library. Various updates. ([0856ea3](https://github.com/alexseitsinger/birdhouse-toolbox/commit/0856ea31bfb0ea8ec4cb545ea343450dfd0a8038))


<a name="v0.2.0"></a>
## [v0.2.0](https://github.com/alexseitsinger/birdhouse-toolbox/compare/v0.1.0...v0.2.0) (2019-05-13)

### Bug Fixes
- fixes imports ([fb0b86f](https://github.com/alexseitsinger/birdhouse-toolbox/commit/fb0b86fcff6a272130f3f74f5793c2f94d5694ec))
- fixes imports ([11efbff](https://github.com/alexseitsinger/birdhouse-toolbox/commit/11efbffb222ffb0b56a802762452de172abf1c8a))
- fixes imports ([b2617a1](https://github.com/alexseitsinger/birdhouse-toolbox/commit/b2617a16b8ae9480fdcc4c297ddd8e9da836d9de))
- fixes imports ([75f02ef](https://github.com/alexseitsinger/birdhouse-toolbox/commit/75f02ef9d5e36e5c3016d5a941852026b19b2123))

### Code Refactoring
- adds options module ([7080f96](https://github.com/alexseitsinger/birdhouse-toolbox/commit/7080f966a0e1fd4009e24ebf342849c4cbb05f93))
- changes settings ([8751f74](https://github.com/alexseitsinger/birdhouse-toolbox/commit/8751f741937c6255e63d909d584ae3db5b5d0ec5))
- fixes order of vars ([1bc40a9](https://github.com/alexseitsinger/birdhouse-toolbox/commit/1bc40a9a894ae4a1c498f72ececfb6c3250e9657))
- imports subgroup ([f81d6c8](https://github.com/alexseitsinger/birdhouse-toolbox/commit/f81d6c8bb2d23132a23d7305ff45f2bf54d0917d))
- moves commands ([c0a0b2c](https://github.com/alexseitsinger/birdhouse-toolbox/commit/c0a0b2c7e7c8252eb782e8b1bcb0c23205575dbe))
- moves commands ([7207138](https://github.com/alexseitsinger/birdhouse-toolbox/commit/72071383915b4789d28e28e1ad1417a852a529f3))
- moves commands ([10b5a88](https://github.com/alexseitsinger/birdhouse-toolbox/commit/10b5a88a910e5f248e3240ea8a694bb5ff08bfe0))
- moves modules ([fa50e06](https://github.com/alexseitsinger/birdhouse-toolbox/commit/fa50e06da2c9fdb11fc6b21e8a5ae8f97608485f))
- moves options ([eb2b4ae](https://github.com/alexseitsinger/birdhouse-toolbox/commit/eb2b4ae48c2ff2c7ae0c9d65765b72b2d01ed5d7))


<a name="v0.1.0"></a>
## [v0.1.0](https://github.com/alexseitsinger/birdhouse-toolbox/compare/dd8ca18695758dccbb80d52d752a8cd66281b35d...v0.1.0) (2019-05-11)


